package com.ruoyi.business.service.impl;

import java.util.Date;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TbUserMapper;
import com.ruoyi.business.domain.TbUser;
import com.ruoyi.business.service.ITbUserService;
import com.ruoyi.common.core.text.Convert;

/**
 * 用户个人信息Service业务层处理
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Service
public class TbUserServiceImpl implements ITbUserService 
{
    @Autowired
    private TbUserMapper tbUserMapper;

    /**
     * 查询用户个人信息
     * 
     * @param userId 用户个人信息主键
     * @return 用户个人信息
     */
    @Override
    public TbUser selectTbUserByUserId(Long userId)
    {
        return tbUserMapper.selectTbUserByUserId(userId);
    }

    /**
     * 查询用户个人信息列表
     * 
     * @param tbUser 用户个人信息
     * @return 用户个人信息
     */
    @Override
    public List<TbUser> selectTbUserList(TbUser tbUser)
    {
        return tbUserMapper.selectTbUserList(tbUser);
    }

    /**
     * 新增用户个人信息
     * 
     * @param tbUser 用户个人信息
     * @return 结果
     */
    @Override
    public int insertTbUser(TbUser tbUser)
    {
        tbUser.setCreateTime(DateUtils.getNowDate());
        return tbUserMapper.insertTbUser(tbUser);
    }

    /**
     * 修改用户个人信息
     * 
     * @param tbUser 用户个人信息
     * @return 结果
     */
    @Override
    public int updateTbUser(TbUser tbUser)
    {
        tbUser.setUpdateTime(DateUtils.getNowDate());
        return tbUserMapper.updateTbUser(tbUser);
    }

    /**
     * 批量删除用户个人信息
     * 
     * @param userIds 需要删除的用户个人信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserByUserIds(String userIds)
    {
        return tbUserMapper.deleteTbUserByUserIds(Convert.toStrArray(userIds));
    }

    /**
     * 删除用户个人信息信息
     * 
     * @param userId 用户个人信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserByUserId(Long userId)
    {
        return tbUserMapper.deleteTbUserByUserId(userId);
    }

    @Override
    public int selectCount(Date startTime, Date endTime) {
        return tbUserMapper.selectCount(startTime, endTime);
    }
}
